package cn.com.qmth.examcloud.service.core.api;

import cn.com.qmth.examcloud.service.core.dao.SchoolRepo;
import cn.com.qmth.examcloud.service.core.entity.School;
import cn.com.qmth.examcloud.service.core.service.SchoolService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

/**
 * 学校服务API
 * Created by songyue on 17/1/14.
 */
@RestController
@RequestMapping("${app.api.root}/school")
public class SchoolApi {

    @Autowired
    SchoolRepo schoolRepo;

    @Autowired
    SchoolService schoolService;

    @ApiOperation(value="查询所有学校",notes="分页")
    @GetMapping("/all/{curPage}/{pageSize}")
    public ResponseEntity getAllSchool(@ModelAttribute School schoolCriteria, @PathVariable Integer curPage, @PathVariable Integer pageSize){
        return schoolService.getAllSchool(schoolCriteria,new PageRequest(curPage - 1,pageSize));
    }

    @ApiOperation(value="查询所有学校",notes="不分页")
    @GetMapping("/all")
    public ResponseEntity getAllSchool(@ModelAttribute School schoolCriteria){
        return schoolService.getAllSchool(schoolCriteria);
    }

    @ApiOperation(value="按ID查询学校",notes="ID查询")
    @GetMapping("/{id}")
    public ResponseEntity<School> getSchoolById(@PathVariable Long id){
        return schoolService.getSchoolById(id);
    }

    @ApiOperation(value="新增学校",notes="新增")
    @PostMapping
    public ResponseEntity addSchool(@ModelAttribute School school){
        return schoolService.saveSchool(school);
    }

    @ApiOperation(value="更新学校",notes="更新")
    @PutMapping
    public ResponseEntity updateSchool(@ModelAttribute School school){
        return schoolService.saveSchool(school);
    }

    @ApiOperation(value="按ID删除学校",notes="删除")
    @DeleteMapping("/{id}")
    public ResponseEntity deleteSchool(@PathVariable Long id){
        return schoolService.deleteSchool(id);
    }
}
