package cn.com.qmth.examcloud.service.core.service;

import cn.com.qmth.examcloud.service.core.dao.CourseRepo;
import cn.com.qmth.examcloud.service.core.entity.Course;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Pageable;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

/**
 * Created by songyue on 17/1/14.
 */
@Service
public class CourseService {

    @Autowired
    CourseRepo courseRepo;

    /**
     * 获取所有课程(分页)
     * @param courseCriteria
     * @param pageable
     * @return
     */
    public ResponseEntity getAllCourse(Course courseCriteria, Pageable pageable){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("code",startsWith())
                .withMatcher("name",startsWith());
        Example<Course> courseExample = Example.of(courseCriteria, exampleMatcher);
        return new ResponseEntity(courseRepo.findAll(courseExample,pageable), HttpStatus.OK);
    }

    /**
     * 获取所有课程
     * @param courseCriteria
     * @return
     */
    public ResponseEntity getAllCourse(Course courseCriteria){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("code",startsWith())
                .withMatcher("name",startsWith());
        Example<Course> courseExample = Example.of(courseCriteria, exampleMatcher);
        return new ResponseEntity(courseRepo.findAll(courseExample), HttpStatus.OK);
    }

    /**
     * 按ID获取课程
     * @param id
     * @return
     */
    public ResponseEntity<Course> getCourseById(Long id){
        return new ResponseEntity<Course>(courseRepo.findOne(id),HttpStatus.OK);
    }

    /**
     * 保存课程
     * @param course
     * @return
     */
    public ResponseEntity saveCourse(Course course){
        return new ResponseEntity(courseRepo.save(course),HttpStatus.OK);
    }

    /**
     * 删除课程
     * @param id
     * @return
     */
    public ResponseEntity deleteCourse(Long id){
        courseRepo.delete(id);
        return new ResponseEntity(HttpStatus.OK);
    }

    /**
     * 删除所有课程
     * @return
     */
    public ResponseEntity deleteAllCourse(){
        courseRepo.deleteAll();
        return new ResponseEntity(HttpStatus.OK);
    }
}
