package cn.com.qmth.examcloud.service.core.service;

import cn.com.qmth.examcloud.service.core.dao.SchoolRepo;
import cn.com.qmth.examcloud.service.core.entity.School;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Pageable;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

/**
 * 学校服务类
 * Created by songyue on 17/1/14.
 */
@Service
public class SchoolService {

    @Autowired
    SchoolRepo schoolRepo;

    /**
     * 获取所有学校(分页)
     * @param schoolCriteria
     * @param pageable
     * @return
     */
    public ResponseEntity getAllSchool(School schoolCriteria, Pageable pageable){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("name",startsWith());
        Example<School> schoolExample = Example.of(schoolCriteria, exampleMatcher);
        return new ResponseEntity(schoolRepo.findAll(schoolExample,pageable), HttpStatus.OK);
    }

    /**
     * 获取所有学校
     * @param schoolCriteria
     * @return
     */
    public ResponseEntity getAllSchool(School schoolCriteria){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("name",startsWith());
        Example<School> schoolExample = Example.of(schoolCriteria, exampleMatcher);
        return new ResponseEntity(schoolRepo.findAll(schoolExample), HttpStatus.OK);
    }

    /**
     * 按ID获取学校
     * @param id
     * @return
     */
    public ResponseEntity<School> getSchoolById(Long id){
        return new ResponseEntity<School>(schoolRepo.findOne(id),HttpStatus.OK);
    }

    /**
     * 保存学校
     * @param school
     * @return
     */
    public ResponseEntity saveSchool(School school){
        return new ResponseEntity(schoolRepo.save(school),HttpStatus.OK);
    }

    /**
     * 删除学校
     * @param id
     * @return
     */
    public ResponseEntity deleteSchool(Long id){
        schoolRepo.delete(id);
        return new ResponseEntity(HttpStatus.OK);
    }

    /**
     * 删除所有学校
     * @return
     */
    public ResponseEntity deleteAllSchool(){
        schoolRepo.deleteAll();
        return new ResponseEntity(HttpStatus.OK);
    }
}
