package cn.com.qmth.examcloud.service.core.service;

import cn.com.qmth.examcloud.service.core.dao.StudentRepo;
import cn.com.qmth.examcloud.service.core.entity.Student;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Pageable;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

/**
 * 学生服务类
 * Created by songyue on 17/1/14.
 */
@Service
public class StudentService {
    @Autowired
    StudentRepo studentRepo;

    /**
     * 获取所有学生(分页)
     * @param studentCriteria
     * @param pageable
     * @return
     */
    public ResponseEntity getAllStudent(Student studentCriteria, Pageable pageable){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("name",startsWith());
        Example<Student> studentExample = Example.of(studentCriteria, exampleMatcher);
        return new ResponseEntity(studentRepo.findAll(studentExample,pageable), HttpStatus.OK);
    }

    /**
     * 获取所有学生
     * @param studentCriteria
     * @return
     */
    public ResponseEntity getAllStudent(Student studentCriteria){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("name",startsWith());
        Example<Student> studentExample = Example.of(studentCriteria, exampleMatcher);
        return new ResponseEntity(studentRepo.findAll(studentExample), HttpStatus.OK);
    }

    /**
     * 按ID获取学生
     * @param id
     * @return
     */
    public ResponseEntity<Student> getStudentById(Long id){
        return new ResponseEntity<Student>(studentRepo.findOne(id),HttpStatus.OK);
    }

    /**
     * 保存学生
     * @param student
     * @return
     */
    public ResponseEntity saveStudent(Student student){
        return new ResponseEntity(studentRepo.save(student),HttpStatus.OK);
    }

    /**
     * 删除学生
     * @param id
     * @return
     */
    public ResponseEntity deleteStudent(Long id){
        studentRepo.delete(id);
        return new ResponseEntity(HttpStatus.OK);
    }

    /**
     * 删除所有学生
     * @return
     */
    public ResponseEntity deleteAllStudent(){
        studentRepo.deleteAll();
        return new ResponseEntity(HttpStatus.OK);
    }
}
